@@ -288,7 +288,7 @@ void KeyCache::addFileSystemWatcher(const std::shared_ptr<FileSystemWatcher> &wa
     connect(watcher.get(), &FileSystemWatcher::fileChanged,
             this, [this]() { startKeyListing(); });
 
-    watcher->setEnabled(d->m_refreshJob == 0);
+    watcher->setEnabled(d->m_refreshJob == nullptr);
 }
 
 void KeyCache::Private::refreshJobDone(const KeyListResult &result)
@@ -761,7 +761,7 @@ void KeyCache::remove(const Key &key)
 
 void KeyCache::remove(const std::vector<Key> &keys)
 {
-    Q_FOREACH (const Key &key, keys) {
+    for (const Key &key : keys) {
         remove(key);
     }
 }
@@ -849,7 +849,7 @@ void KeyCache::insert(const std::vector<Key> &keys)
     pairs.reserve(sorted.size());
     Q_FOREACH (const Key &key, sorted) {
         const std::vector<std::string> emails = ::emails(key);
-        Q_FOREACH (const std::string &e, emails) {
+        for (const std::string &e : emails) {
             pairs.push_back(std::make_pair(e, key));
         }
     }
@@ -1081,10 +1081,29 @@ Error KeyCache::RefreshKeysJob::Private::startKeyListing(GpgME::Protocol proto)
     if (!job) {
         return Error();
     }
+
+#if 0
+    aheinecke: 2017.01.12:
+
+    For unkown reasons the new style connect fails at runtime
+    over library borders into QGpgME from the GpgME repo
+    when cross compiled for Windows and default arguments
+    are used in the Signal.
+
+    This was tested with gcc 4.9 (Mingw 3.0.2) and we could not
+    find an explanation for this. So until this is fixed or we understand
+    the problem we need to use the old style connect for QGpgME signals.
+
+    The new style connect of the canceled signal right below
+    works fine.
+
     connect(job, &QGpgME::ListAllKeysJob::result,
             q, [this](const GpgME::KeyListResult &res, const std::vector<GpgME::Key> &keys) {
                 listAllKeysJobDone(res, keys);
             });
+#endif
+    connect(job, SIGNAL(result(GpgME::KeyListResult,std::vector<GpgME::Key>)),
+            q, SLOT(listAllKeysJobDone(GpgME::KeyListResult,std::vector<GpgME::Key>)));
 
     connect(q, &RefreshKeysJob::canceled, job, &QGpgME::Job::slotCancel);
 
@@ -1104,6 +1123,7 @@ bool KeyCache::initialized() const
 void KeyCache::Private::ensureCachePopulated() const
 {
     if (!m_initalized) {
+        q->startKeyListing();
         QEventLoop loop;
         loop.connect(q, &KeyCache::keyListingDone,
                      &loop, &QEventLoop::quit);
